@@ -34,6 +34,12 @@ PAGINATION_PAGE_SIZE = 25
 MAX_PAGINATION_PAGE_SIZE = 200
 INACTIVE_USER_DAYS = 60
 
+### Configure prism encrypt ###
+if not TESTING:
+    secret_manager = get_secrets_manager()
+    PRISM_ENCRYPT_KEY = secret_manager.get("PRISM_ENCRYPT_KEY")
+else:
+    PRISM_ENCRYPT_KEY = environ.get("PRISM_ENCRYPT_KEY")
 
 ### Configure Flask-SQLAlchemy ###
 SQLALCHEMY_DATABASE_URI = get_sqlalchemy_database_uri(TESTING)
